@@ -1,11 +1,11 @@
 #' @title Insert Values
 #' @description Inserts new values into a vector at specified positions
 #'
-#' @param x        A vector to insert values 
-#' @param y        Values to insert into x
-#' @param l        Index position(s) to insert y values into x
+#' @param x            A vector to insert values 
+#' @param value        Values to insert into x
+#' @param index        Index position(s) to insert y values into x
 #'
-#' @return A vector with values of y inserted into x
+#' @return A vector with values of y inserted into x and the position(s) defined by the index
 #'
 #' @note This function inserts new values at specified positions in a vector. It does not replace existing values. If a single value is provided for y and l represents multiple positions y will be replicated for the length of l. In this way you can insert the same value at multiple locations.  
 #'  
@@ -24,9 +24,12 @@
 #'  insert.values(x, NA, c(2,8))
 #'
 #' @export
-insert.values <- function(x, y, l){
-  if( length(y) != length(l) ) y = rep(y, length(l))
-    x.list <- split(x, cumsum(seq(x) %in% (l)))
-    idx <- order(c(seq_along(x.list), seq_along(y)))
-    as.vector(unlist(c(x.list, y)[idx]))
+insert.values <- function(x, value, index) {
+  if(length(value) == 1) value = rep(value, length(index) )
+  if(length(value) < length(index) ) 
+    stop("length of repacement does not match index")
+  z <- numeric(length(x) + length(index))
+  z[index] <- value
+  z[-index] <- x
+  return(z)  
 }
